@@ -14,8 +14,8 @@ def EDA(df):
     from matplotlib.pyplot import show
     from PyPDF2 import PdfFileMerger
     sns.set(style="darkgrid")
-    #sns.set(rc={'figure.figsize':(11.7,8.27)})
-    sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":300, 'savefig.dpi':300})
+    sns.set(rc={'figure.figsize':(11.7,8.27)})
+    #sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":300, 'savefig.dpi':300})
     pd.options.display.float_format = '{:20,.2f}'.format
     import matplotlib.pyplot as plt
     from matplotlib.backends.backend_pdf import PdfPages
@@ -35,6 +35,11 @@ def EDA(df):
 
     # Any variable with levels greater than below number will be considered as int
     max_threshold_levels_for_integer_datatype=16
+    dpi_value=int(input('Please enter desired DPI value for images 100, 150, 200, 250, 300 \n Note: as DPI values increases runtime increases : '))
+    if dpi_value:
+        pass
+    else:
+        dpi_value=150
     
     #Output pdf name with all the information
     output_pdf='Exploratory_Data_Analysis.pdf'
@@ -81,6 +86,7 @@ def EDA(df):
     variable_dtypes['unique_rate']=variable_dtypes['unique']/variable_dtypes['total_count']
     variable_dtypes[variable_dtypes['unique_rate']==1]['Variable'].to_list()
     percent_missing = df.isnull().sum() * 100 / len(df)
+    
     missing_value_df = pd.DataFrame({'Variable': df.columns,'percent_missing': percent_missing})
 
     variable_dtypes=variable_dtypes.merge(missing_value_df,on='Variable', how='left')
@@ -118,40 +124,42 @@ def EDA(df):
     print('#'*100)
     print('Data types changed')
     print('#'*100)
+    
+    df_metadata_to_pdf=df_metadata
     if 'max' in df_metadata.columns:
-        df_metadata_to_pdf=df_metadata
         df_metadata_to_pdf['range'] = df_metadata_to_pdf['max']-df_metadata_to_pdf['min']
-        df_metadata_to_pdf.rename(columns={'unique': 'cardinality','50%': 'median'}, inplace=True)
-        df_metadata_to_pdf = df_metadata_to_pdf.astype({'cardinality': int})
-        df_metadata_to_pdf.drop(['total_count','min','max','25%','75%','unique_rate'],axis=1,inplace=True)
-        #write_to_html_file(df_metadata_to_pdf, main_title_inside_pdf,sub_title_inside_pdf,sub1_title_inside_pdf,directory_path_of_data+'/'+project_name+'.html')
-        print('#'*100)
-        print('Generating CSV of summary statistics')
-        print('#'*100)
-        df_metadata_to_pdf.to_csv(directory_path_of_data+'Summary_Statistics.csv')
-        print('Check the Summary_Statistics.csv in the following directory '+directory_path_of_data, '!!')
-        print('#'*100)
-        print('Completed CSV generation of summary statistics')
-        print('#'*100)
-        print('#'*100)
-        print('Generating PDF of summary statistics')
-        print('#'*100)
-        fig, ax =plt.subplots(figsize=(12,4))
-        ax.axis('tight')
-        ax.axis('off')
-        ax.set_title('Summary Statistics Plot')
-        the_table = ax.table(cellText=df_metadata_to_pdf.values,colLabels=df_metadata_to_pdf.columns,loc='center')
+    df_metadata_to_pdf.rename(columns={'unique': 'cardinality','50%': 'median'}, inplace=True)
+    df_metadata_to_pdf = df_metadata_to_pdf.astype({'cardinality': int})
+    #if 'max' in df_metadata.columns:
+        #df_metadata_to_pdf.drop(['total_count','min','max','25%','75%','unique_rate'],axis=1,inplace=True)
+    #write_to_html_file(df_metadata_to_pdf, main_title_inside_pdf,sub_title_inside_pdf,sub1_title_inside_pdf,directory_path_of_data+'/'+project_name+'.html')
+    print('#'*100)
+    print('Generating CSV of summary statistics')
+    print('#'*100)
+    df_metadata_to_pdf.to_csv(directory_path_of_data+'Summary_Statistics.csv')
+    print('Check the Summary_Statistics.csv in the following directory '+directory_path_of_data, '!!')
+    print('#'*100)
+    print('Completed CSV generation of summary statistics')
+    print('#'*100)
+    print('#'*100)
+    print('Generating PDF of summary statistics')
+    print('#'*100)
+    fig, ax =plt.subplots(figsize=(12,4))
+    ax.axis('tight')
+    ax.axis('off')
+    ax.set_title('Summary Statistics Plot')
+    the_table = ax.table(cellText=df_metadata_to_pdf.values,colLabels=df_metadata_to_pdf.columns,loc='center')
 
 
-        pp = PdfPages('summary_stats.pdf')
-        pp.savefig(fig, bbox_inches='tight')
-        pp.close()
+    pp = PdfPages('summary_stats.pdf')
+    pp.savefig(fig, bbox_inches='tight')
+    pp.close()
 
 
-        print('#'*100)
-        print('Completed PDF generation summary statistics')
-        print('#'*100)
-
+    print('#'*100)
+    print('Completed PDF generation summary statistics')
+    print('#'*100)
+    if 'max' in df_metadata.columns:
         print('#'*100)
         print('Starting Integer data type variables exploratory analysis ')
         print('#'*100)
@@ -163,7 +171,7 @@ def EDA(df):
         df_int=df_int.drop(variable_d1types[(variable_d1types['unique']>max_threshold_levels_for_integer_datatype)]['Variable'].to_list(),axis=1)
 
         total = float(len(df_int))
-        sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":300, 'savefig.dpi':300})
+        sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":dpi_value, 'savefig.dpi':dpi_value})
         for cole in df_int.columns:
             ax = sns.countplot(x=cole, data=df_int) # for Seaborn version 0.7 and more
             ax.set_title(cole+" (% based on total records="+str(int(total))+")", fontsize=12)
@@ -219,7 +227,7 @@ def EDA(df):
         print('#'*100)
         print('Starting Float data type variables exploratory analysis ')
         print('#'*100)
-        sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":300, 'savefig.dpi':300})
+        sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":dpi_value, 'savefig.dpi':dpi_value})
         df_float=df.select_dtypes(include=['float'])
         for cole in df_float.columns:
             mean=df_float[cole].mean()
@@ -293,7 +301,7 @@ def EDA(df):
     del list_strings_to_drop1
     del list_strings_to_drop2
     
-    sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":300, 'savefig.dpi':300})
+    sns.set(rc={'figure.figsize':(11.7,8.27),"figure.dpi":dpi_value, 'savefig.dpi':dpi_value})
     total = float(len(df_string)) 
     for cole in df_string.columns:
         ax = sns.countplot(x=cole, data=df_string) # for Seaborn version 0.7 and more
